@@ -416,7 +416,7 @@ function UpdateNotifier() {
 
   var idle = Cc["@mozilla.org/timer;1"].createInstance(Ci.nsITimer);
   idle.initWithCallback(function() {
-    let kungFuDeathGrip = idle;
+    let anchor = idle;
     watchOneDir(NS_XPCOM_CURRENT_PROCESS_DIR, [], "app");
     watchOneDir(NS_GRE_DIR, [], "app");
     watchOneDir(NS_APP_PLUGINS_DIR, [], "plugins");
@@ -436,7 +436,7 @@ function UpdateNotifier() {
     //                            ["extensions"]).path]);
 
     idle.initWithCallback(function() {
-      let kungFuDeathGrip = idle;
+      let anchor = idle;
       // Would use the AddonManager here, but it doesn't expose full paths.
       // We use a delay here to avoid starting the plugin host at startup
       // if it isn't otherwise needed
